@@ -32,10 +32,11 @@ from shutil import rmtree
 from tempfile import mkdtemp
 
 from nose.plugins.skip import SkipTest
+from monkeypatch import Patch
 from testrunner import VdsmTestCase, permutations, expandPermutations
 from testValidation import checkSudo, ValidateRunningAsRoot
 
-from vdsm.utils import execCmd
+from vdsm.utils import execCmd, stopwatch
 import storage
 import mkimage
 
@@ -54,17 +55,11 @@ class MkimageTestCase(VdsmTestCase):
         by mkimage._commonCleanFs.
         Avoid errors creating _P_PAYLOAD_IMAGES
         """
-        # pylint: disable=W0212
-        self.orig_mkimage = {
-            "DISKIMAGE_USER": mkimage.DISKIMAGE_USER,
-            "DISKIMAGE_GROUP": mkimage.DISKIMAGE_GROUP,
-            "_P_PAYLOAD_IMAGES": mkimage._P_PAYLOAD_IMAGES
-        }
-        self.workdir = mkdtemp()
-        self.img_dir = mkdtemp()
-        mkimage.DISKIMAGE_USER = -1
-        mkimage.DISKIMAGE_GROUP = -1
-        mkimage._P_PAYLOAD_IMAGES = self.img_dir
+        self.tempdir = mkdtemp(prefix="vdsm-mkimage-tests")
+        self.workdir = os.path.join(self.tempdir, "work")
+        os.mkdir(self.workdir)
+        self.img_dir = os.path.join(self.tempdir, "images")
+        os.mkdir(self.img_dir)
         self.files = {}
         self.expected_results = {}
         self.subdir = os.path.join('a', 'subdirectory', 'for', 'testing')
@@ -77,17 +72,22 @@ class MkimageTestCase(VdsmTestCase):
             self.expected_results[longpath] = content
             self.files[longpath] = b64encode(content)
 
+        self.patch = Patch([
+            (mkimage, "DISKIMAGE_USER", -1),
+            (mkimage, "DISKIMAGE_GROUP", -1),
+            (mkimage, "_P_PAYLOAD_IMAGES", self.img_dir),
+        ])
+
+        # Must be last; if setUp fails, tearDown is not invoked
+        self.patch.apply()
+
     def tearDown(self):
         """
         Removes the workdir and its content when finished.
         Restore original values of mkimage constants.
         """
-        rmtree(self.workdir)
-        rmtree(self.img_dir)
-        mkimage.DISKIMAGE_USER = self.orig_mkimage["DISKIMAGE_USER"]
-        mkimage.DISKIMAGE_GROUP = self.orig_mkimage["DISKIMAGE_GROUP"]
-        # pylint: disable=W0212
-        mkimage._P_PAYLOAD_IMAGES = self.orig_mkimage["_P_PAYLOAD_IMAGES"]
+        self.patch.revert()
+        rmtree(self.tempdir)
 
     def _check_permissions(self, filepath, permsMask):
         """
@@ -173,8 +173,10 @@ class MkimageTestCase(VdsmTestCase):
             self._check_content(checkPerms=False)
             self._check_label(floppy, label)
         finally:
-            m.umount(force=True)
-            os.unlink(floppy)
+            m.umount(force=True, freeloop=True)
+            # TODO: Use libudev to wait for specific event
+            with stopwatch("Wait for udev events"):
+                storage.udevadm.settle(5)
 
     @permutations([[None], ['fslabel']])
     def test_mkIsoFs(self, label):
@@ -203,8 +205,10 @@ class MkimageTestCase(VdsmTestCase):
                                      (stat.S_IWOTH, False),
                                      (stat.S_IXOTH, False)))
         finally:
-            m.umount(force=True)
-            os.unlink(iso_img)
+            m.umount(force=True, freeloop=True)
+            # TODO: Use libudev to wait for specific event
+            with stopwatch("Wait for udev events"):
+                storage.udevadm.settle(5)
 
     def test_removeFs(self):
         """
