@@ -69,10 +69,6 @@ HOST_STATUS_FAIL = "fail"
 HOST_STATUS_DEAD = "dead"
 
 
-class InquireNotSupportedError(Exception):
-    """Raised when the clusterlock class is not supporting inquire"""
-
-
 class SafeLease(object):
     log = logging.getLogger("Storage.SafeLease")
 
@@ -132,7 +128,8 @@ class SafeLease(object):
             acquireLockCommand = subprocess.list2cmdline([
                 lockUtil, "start", self._sdUUID, str(hostID),
                 str(self._lockRenewalIntervalSec), str(self._leasesPath),
-                str(leaseTimeMs), str(ioOpTimeoutMs), str(self._leaseFailRetry)
+                str(leaseTimeMs), str(ioOpTimeoutMs),
+                str(self._leaseFailRetry), str(os.getpid())
             ])
 
             cmd = [constants.EXT_SU, misc.IOUSER, '-s', constants.EXT_SH, '-c',
@@ -146,7 +143,7 @@ class SafeLease(object):
             self.log.debug("Clustered lock acquired successfully")
 
     def inquire(self):
-        raise InquireNotSupportedError()
+        raise se.InquireNotSupportedError()
 
     def getLockUtilFullPath(self):
         return os.path.join(self.lockUtilPath, self.lockCmd)
